<?php

namespace Qcloud\Sms;

use Qcloud\Sms\SmsSenderUtil;

/**
 * 拉取短信状态类
 *
 */
class SmsSendStatus
{
    private $url;
    private $appid;
    private $appkey;
    private $util;

    /**
     * 构造函数
     *
     * @param string $appid  sdkappid
     * @param string $appkey sdkappid对应的appkey
     */
    public function __construct($appid, $appkey)
    {
        $this->url = "https://yun.tim.qq.com/v5/tlssmssvr/pullsendstatus";
        $this->appid =  $appid;
        $this->appkey = $appkey;
        $this->util = new SmsSenderUtil();
    }

    /**
     * 拉取回执结果
     *
     * @param number $begin_date 开始时间，yyyymmddhh 需要拉取的起始时间,精确到小时
     * @param number $end_date   结束时间，yyyymmddhh 需要拉取的截止时间,精确到小时
     * @return string 应答json字符串，详细内容参见腾讯云协议文档
     */
    public function pull($begin_date, $end_date)
    {
        $random = $this->util->getRandom();
        $curTime = time();
        $wholeUrl = $this->url . "?sdkappid=" . $this->appid . "&random=" . $random;

        $data = new \stdClass();
        $data->sig = $this->util->calculateSigForPuller($this->appkey, $random, $curTime);
        $data->time = $curTime;
        $data->begin_date = (int) $begin_date;
        $data->end_date = (int) $end_date;

        return $this->util->sendCurlPost($wholeUrl, $data);
    }
}